The Transport Tribunal heard appeals from decisions of the Traffic Commissioners and of the Registrar of the Driving Standards Agency (subsequently the Registrar of Approved Driving Instructors). Traffic Commissioners are responsible for the licensing and regulation of those who operate heavy goods vehicles, buses and coaches. The Registrar of Approved Driving Instructors is responsible for maintaining the integrity of the Register of Approved Driving Instructors. In 2009 appeals from the Traffic Commissioners were transferred to the Upper Tribunal Administrative Appeals Chamber and appeals from the Registrar of Approved Driving Instructors were transferred to the General Regulatory Chamber of the First–tier Tribunal.
